@@ -13,8 +13,6 @@
  * in SWIG.  --MR
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_directors_cxx[] = "$Id";
-
 #include "swigmod.h"
 
 /* Swig_csuperclass_call()
@@ -78,9 +76,10 @@ String *Swig_class_name(Node *n) {
 
 String *Swig_director_declaration(Node *n) {
   String *classname = Swig_class_name(n);
-  String *directorname = NewStringf("SwigDirector_%s", classname);
+  String *directorname = Language::instance()->directorClassName(n);
   String *base = Getattr(n, "classtype");
   String *declaration = Swig_class_declaration(n, directorname);
+
   Printf(declaration, " : public %s, public Swig::Director {\n", base);
   Delete(classname);
   Delete(directorname);
@@ -276,13 +275,14 @@ String *Swig_method_decl(SwigType *rettype, SwigType *decl, const_String_or_char
 void Swig_director_emit_dynamic_cast(Node *n, Wrapper *f) {
   // TODO: why is the storage element removed in staticmemberfunctionHandler ??
   if ((!is_public(n) && (is_member_director(n) || GetFlag(n, "explicitcall"))) || 
-      (is_non_virtual_protected_access(n) && !(checkAttribute(n, "staticmemberfunctionHandler:storage", "static") || 
-                                               checkAttribute(n, "storage", "static"))
+      (is_non_virtual_protected_access(n) && !(Swig_storage_isstatic_custom(n, "staticmemberfunctionHandler:storage") || 
+                                               Swig_storage_isstatic(n))
                                           && !Equal(nodeType(n), "constructor"))) {
     Node *parent = Getattr(n, "parentNode");
-    String *symname = Getattr(parent, "sym:name");
-    String *dirname = NewStringf("SwigDirector_%s", symname);
-    String *dirdecl = NewStringf("%s *darg = 0", dirname);
+    String *dirname;
+    String *dirdecl;
+    dirname = Language::instance()->directorClassName(parent);
+    dirdecl = NewStringf("%s *darg = 0", dirname);
     Wrapper_add_local(f, "darg", dirdecl);
     Printf(f->code, "darg = dynamic_cast<%s *>(arg1);\n", dirname);
     Delete(dirname);
