@@ -43,7 +43,7 @@
 #include <errno.h>
 
 static const char *usage = "\
-PHP Options (available with -php)\n\
+PHP Options (available with -php7)\n\
      -noproxy         - Don't generate proxy classes.\n\
      -prefix <prefix> - Prepend <prefix> to all class names in PHP wrappers\n\
 \n";
@@ -100,6 +100,11 @@ static String *s_oowrappers;
 static String *s_fakeoowrappers;
 static String *s_phpclasses;
 
+/* To reduce code size (generated and compiled) we only want to emit each
+ * different arginfo once, so we need to track which have been used.
+ */
+static Hash *arginfo_used;
+
 /* Variables for using PHP classes */
 static Node *current_class = 0;
 
@@ -129,6 +134,7 @@ extern "C" {
 
 static void SwigPHP_emit_resource_registrations() {
   Iterator ki;
+  bool emitted_default_dtor = false;
 
   if (!zend_types)
     return;
@@ -140,9 +146,7 @@ static void SwigPHP_emit_resource_registrations() {
     DOH *key = ki.key;
     Node *class_node = ki.item;
     String *human_name = key;
-
-    // Write out destructor function header
-    Printf(s_wrappers, "static ZEND_RSRC_DTOR_FUNC(_wrap_destroy%s) {\n", key);
+    String *rsrc_dtor_name = NULL;
 
     // write out body
     if (class_node != NOTCLASS) {
@@ -152,51 +156,42 @@ static void SwigPHP_emit_resource_registrations() {
         human_name = Getattr(class_node, "name");
       // Do we have a known destructor for this type?
       if (destructor) {
-        Printf(s_wrappers, "  %s(rsrc, SWIGTYPE%s->name TSRMLS_CC);\n", destructor, key);
-      } else {
-        Printf(s_wrappers, "  /* No destructor for class %s */\n", human_name);
-        Printf(s_wrappers, "  efree(rsrc->ptr);\n");
+	rsrc_dtor_name = NewStringf("_wrap_destroy%s", key);
+	// Write out custom destructor function
+	Printf(s_wrappers, "static ZEND_RSRC_DTOR_FUNC(%s) {\n", rsrc_dtor_name);
+        Printf(s_wrappers, "  %s(res, SWIGTYPE%s->name);\n", destructor, key);
+	Printf(s_wrappers, "}\n");
       }
-    } else {
-      Printf(s_wrappers, "  /* No destructor for simple type %s */\n", key);
-      Printf(s_wrappers, "  efree(rsrc->ptr);\n");
     }
 
-    // close function
-    Printf(s_wrappers, "}\n");
+    if (!rsrc_dtor_name) {
+      rsrc_dtor_name = NewString("_swig_default_rsrc_destroy");
+      if (!emitted_default_dtor) {
+	// Write out custom destructor function
+	Printf(s_wrappers, "static ZEND_RSRC_DTOR_FUNC(%s) {\n", rsrc_dtor_name);
+	Printf(s_wrappers, "  efree(res->ptr);\n");
+	Printf(s_wrappers, "}\n");
+	emitted_default_dtor = true;
+      }
+    }
 
     // declare le_swig_<mangled> to store php registration
     Printf(s_vdecl, "static int le_swig_%s=0; /* handle for %s */\n", key, human_name);
 
     // register with php
     Printf(s_oinit, "le_swig_%s=zend_register_list_destructors_ex"
-		    "(_wrap_destroy%s,NULL,(char *)(SWIGTYPE%s->name),module_number);\n", key, key, key);
+		    "(%s, NULL, SWIGTYPE%s->name, module_number);\n", key, rsrc_dtor_name, key);
 
     // store php type in class struct
     Printf(s_oinit, "SWIG_TypeClientData(SWIGTYPE%s,&le_swig_%s);\n", key, key);
 
+    Delete(rsrc_dtor_name);
+
     ki = Next(ki);
   }
 }
 
 class PHP : public Language {
-  String *emit_action(Node *n) {
-    // Adjust wrap:action to add TSRMLS_CC.
-    String * action = Getattr(n, "wrap:action");
-    if (action) {
-      char * p = Strstr(action, "Swig::DirectorPureVirtualException::raise(\"");
-      if (p) {
-	p += strlen("Swig::DirectorPureVirtualException::raise(\"");
-	p = strchr(p, '"');
-	if (p) {
-	  ++p;
-	  Insert(action, (int)(p - Char(action)), " TSRMLS_CC");
-	}
-      }
-    }
-    return ::emit_action(n);
-  }
-
 public:
   PHP() {
     director_language = 1;
@@ -208,7 +203,6 @@ public:
 
   virtual void main(int argc, char *argv[]) {
     SWIG_library_directory("php");
-    SWIG_config_cppext("cpp");
 
     for (int i = 1; i < argc; i++) {
       if (strcmp(argv[i], "-prefix") == 0) {
@@ -225,25 +219,11 @@ public:
 	Swig_mark_arg(i);
       } else if (strcmp(argv[i], "-help") == 0) {
 	fputs(usage, stdout);
-      } else if (strcmp(argv[i], "-make") == 0 ||
-		 strcmp(argv[i], "-withc") == 0 ||
-		 strcmp(argv[i], "-withcxx") == 0) {
-	Printf(stderr, "*** %s is no longer supported.\n", argv[i]);
-	SWIG_exit(EXIT_FAILURE);
-      } else if (strcmp(argv[i], "-phpfull") == 0 ||
-		 strcmp(argv[i], "-withlibs") == 0 ||
-		 strcmp(argv[i], "-withincs") == 0) {
-	Printf(stderr, "*** %s is no longer supported.\n*** We recommend building as a dynamically loadable module.\n", argv[i]);
-	SWIG_exit(EXIT_FAILURE);
-      } else if (strcmp(argv[i], "-dlname") == 0) {
-	Printf(stderr, "*** -dlname is no longer supported.\n*** If you want to change the module name, use -module instead.\n");
-	SWIG_exit(EXIT_FAILURE);
       }
     }
 
     Preprocessor_define("SWIGPHP 1", 0);
-    // SWIGPHP5 is deprecated, and no longer documented.
-    Preprocessor_define("SWIGPHP5 1", 0);
+    Preprocessor_define("SWIGPHP7 1", 0);
     SWIG_typemap_lang("php");
     SWIG_config_file("php.swg");
     allow_overloading();
@@ -267,7 +247,7 @@ public:
     }
 
     /* Set comparison with null for ConstructorToFunction */
-    setSubclassInstanceCheck(NewString("$arg->type != IS_NULL"));
+    setSubclassInstanceCheck(NewString("Z_TYPE_P($arg) != IS_NULL"));
 
     /* Initialize all of the output files */
     String *outfile = Getattr(n, "outfile");
@@ -282,14 +262,14 @@ public:
     f_runtime = NewStringEmpty();
 
     /* sections of the output file */
-    s_init = NewString("/* init section */\n");
-    r_init = NewString("/* rinit section */\n");
-    s_shutdown = NewString("/* shutdown section */\n");
-    r_shutdown = NewString("/* rshutdown section */\n");
+    s_init = NewStringEmpty();
+    r_init = NewStringEmpty();
+    s_shutdown = NewStringEmpty();
+    r_shutdown = NewStringEmpty();
     s_header = NewString("/* header section */\n");
     s_wrappers = NewString("/* wrapper section */\n");
     /* subsections of the init section */
-    s_vinit = NewString("/* vinit subsection */\n");
+    s_vinit = NewStringEmpty();
     s_vdecl = NewString("/* vdecl subsection */\n");
     s_cinit = NewString("/* cinit subsection */\n");
     s_oinit = NewString("/* oinit subsection */\n");
@@ -382,7 +362,7 @@ public:
 
     /* Initialize the rest of the module */
 
-    Printf(s_oinit, "ZEND_INIT_MODULE_GLOBALS(%s, %s_init_globals, %s_destroy_globals);\n", module, module, module);
+    Printf(s_oinit, "ZEND_INIT_MODULE_GLOBALS(%s, %s_init_globals, NULL);\n", module, module);
 
     /* start the header section */
     Printf(s_header, "ZEND_BEGIN_MODULE_GLOBALS(%s)\n", module);
@@ -390,21 +370,16 @@ public:
     Printf(s_header, "int error_code;\n");
     Printf(s_header, "ZEND_END_MODULE_GLOBALS(%s)\n", module);
     Printf(s_header, "ZEND_DECLARE_MODULE_GLOBALS(%s)\n", module);
-    Printf(s_header, "#ifdef ZTS\n");
-    Printf(s_header, "#define SWIG_ErrorMsg() TSRMG(%s_globals_id, zend_%s_globals *, error_msg )\n", module, module);
-    Printf(s_header, "#define SWIG_ErrorCode() TSRMG(%s_globals_id, zend_%s_globals *, error_code )\n", module, module);
-    Printf(s_header, "#else\n");
     Printf(s_header, "#define SWIG_ErrorMsg() (%s_globals.error_msg)\n", module);
     Printf(s_header, "#define SWIG_ErrorCode() (%s_globals.error_code)\n", module);
-    Printf(s_header, "#endif\n\n");
 
     /* The following can't go in Lib/php/phprun.swg as it uses SWIG_ErrorMsg(), etc
      * which has to be dynamically generated as it depends on the module name.
      */
     Append(s_header, "#ifdef __GNUC__\n");
-    Append(s_header, "static void SWIG_FAIL(TSRMLS_D) __attribute__ ((__noreturn__));\n");
+    Append(s_header, "static void SWIG_FAIL(void) __attribute__ ((__noreturn__));\n");
     Append(s_header, "#endif\n\n");
-    Append(s_header, "static void SWIG_FAIL(TSRMLS_D) {\n");
+    Append(s_header, "static void SWIG_FAIL(void) {\n");
     Append(s_header, "    zend_error(SWIG_ErrorCode(), \"%s\", SWIG_ErrorMsg());\n");
     // zend_error() should never return with the parameters we pass, but if it
     // does, we really don't want to let SWIG_FAIL() return.  This also avoids
@@ -417,41 +392,36 @@ public:
     Printf(s_header, "  globals->error_code = default_error_code;\n");
     Printf(s_header, "}\n");
 
-    Printf(s_header, "static void %s_destroy_globals(zend_%s_globals * globals) { (void)globals; }\n", module, module);
-
-    Printf(s_header, "\n");
-    Printf(s_header, "static void SWIG_ResetError(TSRMLS_D) {\n");
+    Printf(s_header, "static void SWIG_ResetError(void) {\n");
     Printf(s_header, "  SWIG_ErrorMsg() = default_error_msg;\n");
     Printf(s_header, "  SWIG_ErrorCode() = default_error_code;\n");
     Printf(s_header, "}\n");
 
     Append(s_header, "\n");
     Printf(s_header, "ZEND_NAMED_FUNCTION(_wrap_swig_%s_alter_newobject) {\n", module);
-    Append(s_header, "  zval **args[2];\n");
+    Append(s_header, "  zval args[2];\n");
     Append(s_header, "  swig_object_wrapper *value;\n");
-    Append(s_header, "  int type;\n");
     Append(s_header, "\n");
-    Append(s_header, "  SWIG_ResetError(TSRMLS_C);\n");
+    Append(s_header, "  SWIG_ResetError();\n");
     Append(s_header, "  if(ZEND_NUM_ARGS() != 2 || zend_get_parameters_array_ex(2, args) != SUCCESS) {\n");
     Append(s_header, "    WRONG_PARAM_COUNT;\n");
     Append(s_header, "  }\n");
     Append(s_header, "\n");
-    Append(s_header, "  value = (swig_object_wrapper *) zend_list_find((*args[0])->value.lval, &type);\n");
-    Append(s_header, "  value->newobject = zval_is_true(*args[1]);\n");
+    Append(s_header, "  value = (swig_object_wrapper *) Z_RES_VAL(args[0]);\n");
+    Append(s_header, "  value->newobject = zval_is_true(&args[1]);\n");
     Append(s_header, "\n");
     Append(s_header, "  return;\n");
     Append(s_header, "}\n");
     Printf(s_header, "ZEND_NAMED_FUNCTION(_wrap_swig_%s_get_newobject) {\n", module);
-    Append(s_header, "  zval **args[1];\n");
+    Append(s_header, "  zval args[1];\n");
     Append(s_header, "  swig_object_wrapper *value;\n");
-    Append(s_header, "  int type;\n");
     Append(s_header, "\n");
-    Append(s_header, "  SWIG_ResetError(TSRMLS_C);\n");
+    Append(s_header, "  SWIG_ResetError();\n");
     Append(s_header, "  if(ZEND_NUM_ARGS() != 1 || zend_get_parameters_array_ex(1, args) != SUCCESS) {\n");
     Append(s_header, "    WRONG_PARAM_COUNT;\n");
     Append(s_header, "  }\n");
     Append(s_header, "\n");
-    Append(s_header, "  value = (swig_object_wrapper *) zend_list_find((*args[0])->value.lval, &type);\n");
+    Append(s_header, "  value = (swig_object_wrapper *) Z_RES_VAL(args[0]);\n");
     Append(s_header, "  RETVAL_LONG(value->newobject);\n");
     Append(s_header, "\n");
     Append(s_header, "  return;\n");
@@ -496,17 +466,10 @@ public:
     Printf(f_h, "#else\n");
     Printf(f_h, "# define PHP_%s_API\n", cap_module);
     Printf(f_h, "#endif\n\n");
-    Printf(f_h, "#ifdef ZTS\n");
-    Printf(f_h, "#include \"TSRM.h\"\n");
-    Printf(f_h, "#endif\n\n");
-    Printf(f_h, "PHP_MINIT_FUNCTION(%s);\n", module);
-    Printf(f_h, "PHP_MSHUTDOWN_FUNCTION(%s);\n", module);
-    Printf(f_h, "PHP_RINIT_FUNCTION(%s);\n", module);
-    Printf(f_h, "PHP_RSHUTDOWN_FUNCTION(%s);\n", module);
-    Printf(f_h, "PHP_MINFO_FUNCTION(%s);\n\n", module);
 
     /* start the arginfo section */
     s_arginfo = NewString("/* arginfo subsection */\n");
+    arginfo_used = NewHash();
 
     /* start the function entry section */
     s_entry = NewString("/* entry subsection */\n");
@@ -518,45 +481,66 @@ public:
     Printf(s_entry, "/* Every non-class user visible function must have an entry here */\n");
     Printf(s_entry, "static zend_function_entry %s_functions[] = {\n", module);
 
-    /* start the init section */
-    Append(s_init, "#if ZEND_MODULE_API_NO <= 20090626\n");
-    Append(s_init, "#undef ZEND_MODULE_BUILD_ID\n");
-    Append(s_init, "#define ZEND_MODULE_BUILD_ID (char*)\"API\" ZEND_TOSTR(ZEND_MODULE_API_NO) ZEND_BUILD_TS ZEND_BUILD_DEBUG ZEND_BUILD_SYSTEM ZEND_BUILD_EXTRA\n");
-    Append(s_init, "#endif\n");
-    Printv(s_init, "zend_module_entry ", module, "_module_entry = {\n", NIL);
-    Printf(s_init, "    STANDARD_MODULE_HEADER,\n");
-    Printf(s_init, "    (char*)\"%s\",\n", module);
-    Printf(s_init, "    %s_functions,\n", module);
-    Printf(s_init, "    PHP_MINIT(%s),\n", module);
-    Printf(s_init, "    PHP_MSHUTDOWN(%s),\n", module);
-    Printf(s_init, "    PHP_RINIT(%s),\n", module);
-    Printf(s_init, "    PHP_RSHUTDOWN(%s),\n", module);
-    Printf(s_init, "    PHP_MINFO(%s),\n", module);
-    Printf(s_init, "    NO_VERSION_YET,\n");
-    Printf(s_init, "    STANDARD_MODULE_PROPERTIES\n");
-    Printf(s_init, "};\n");
-    Printf(s_init, "zend_module_entry* SWIG_module_entry = &%s_module_entry;\n\n", module);
+    /* Emit all of the code */
+    Language::top(n);
 
-    Printf(s_init, "#ifdef __cplusplus\n");
-    Printf(s_init, "extern \"C\" {\n");
-    Printf(s_init, "#endif\n");
-    // We want to write "SWIGEXPORT ZEND_GET_MODULE(%s)" but ZEND_GET_MODULE
-    // in PHP5 has "extern "C" { ... }" around it so we can't do that.
-    Printf(s_init, "SWIGEXPORT zend_module_entry *get_module(void) { return &%s_module_entry; }\n", module);
-    Printf(s_init, "#ifdef __cplusplus\n");
-    Printf(s_init, "}\n");
-    Printf(s_init, "#endif\n\n");
+    SwigPHP_emit_resource_registrations();
+
+    /* start the init section */
+    {
+      String * s_init_old = s_init;
+      s_init = NewString("/* init section */\n");
+      Printv(s_init, "zend_module_entry ", module, "_module_entry = {\n", NIL);
+      Printf(s_init, "    STANDARD_MODULE_HEADER,\n");
+      Printf(s_init, "    \"%s\",\n", module);
+      Printf(s_init, "    %s_functions,\n", module);
+      Printf(s_init, "    PHP_MINIT(%s),\n", module);
+      if (Len(s_shutdown) > 0) {
+	Printf(s_init, "    PHP_MSHUTDOWN(%s),\n", module);
+      } else {
+	Printf(s_init, "    NULL, /* No MSHUTDOWN code */\n");
+      }
+      if (Len(r_init) > 0 || Len(s_vinit) > 0) {
+	Printf(s_init, "    PHP_RINIT(%s),\n", module);
+      } else {
+	Printf(s_init, "    NULL, /* No RINIT code */\n");
+      }
+      if (Len(r_shutdown) > 0) {
+	Printf(s_init, "    PHP_RSHUTDOWN(%s),\n", module);
+      } else {
+	Printf(s_init, "    NULL, /* No RSHUTDOWN code */\n");
+      }
+      if (Len(pragma_phpinfo) > 0) {
+	Printf(s_init, "    PHP_MINFO(%s),\n", module);
+      } else {
+	Printf(s_init, "    NULL, /* No MINFO code */\n");
+      }
+      Printf(s_init, "    NO_VERSION_YET,\n");
+      Printf(s_init, "    STANDARD_MODULE_PROPERTIES\n");
+      Printf(s_init, "};\n");
+      Printf(s_init, "zend_module_entry* SWIG_module_entry = &%s_module_entry;\n\n", module);
+
+      Printf(s_init, "#ifdef __cplusplus\n");
+      Printf(s_init, "extern \"C\" {\n");
+      Printf(s_init, "#endif\n");
+      // We want to write "SWIGEXPORT ZEND_GET_MODULE(%s)" but ZEND_GET_MODULE
+      // in PHP5 has "extern "C" { ... }" around it so we can't do that.
+      Printf(s_init, "SWIGEXPORT zend_module_entry *get_module(void) { return &%s_module_entry; }\n", module);
+      Printf(s_init, "#ifdef __cplusplus\n");
+      Printf(s_init, "}\n");
+      Printf(s_init, "#endif\n\n");
+
+      Printf(s_init, "#define SWIG_php_minit PHP_MINIT_FUNCTION(%s)\n\n", module);
+
+      Printv(s_init, s_init_old, NIL);
+      Delete(s_init_old);
+    }
 
     /* We have to register the constants before they are (possibly) used
      * by the pointer typemaps. This all needs re-arranging really as
      * things are being called in the wrong order
      */
-    Printf(s_init, "#define SWIG_php_minit PHP_MINIT_FUNCTION(%s)\n", module);
 
-    /* Emit all of the code */
-    Language::top(n);
-
-    SwigPHP_emit_resource_registrations();
     //    Printv(s_init,s_resourcetypes,NIL);
     /* We need this after all classes written out by ::top */
     Printf(s_oinit, "CG(active_class_entry) = NULL;\n");
@@ -573,38 +557,66 @@ public:
     Printf(s_init, "}\n\n");
 
     // Now do REQUEST init which holds any user specified %rinit, and also vinit
-    Printf(s_init, "PHP_RINIT_FUNCTION(%s)\n{\n", module);
-    Printf(s_init, "%s\n", r_init);
+    if (Len(r_init) > 0 || Len(s_vinit) > 0) {
+      Printf(f_h, "PHP_RINIT_FUNCTION(%s);\n", module);
 
-    /* finish our init section which will have been used by class wrappers */
-    Printf(s_vinit, "/* end vinit subsection */\n");
-    Printf(s_init, "%s\n", s_vinit);
-    Clear(s_vinit);
-    Delete(s_vinit);
+      Printf(s_init, "PHP_RINIT_FUNCTION(%s)\n{\n", module);
+      if (Len(r_init) > 0) {
+	Printv(s_init,
+	       "/* rinit section */\n",
+	       r_init, "\n",
+	       NIL);
+      }
 
-    Printf(s_init, "    return SUCCESS;\n");
-    Printf(s_init, "}\n\n");
+      if (Len(s_vinit) > 0) {
+	/* finish our init section which will have been used by class wrappers */
+	Printv(s_init,
+	       "/* vinit subsection */\n",
+	       s_vinit, "\n"
+	       "/* end vinit subsection */\n",
+	       NIL);
+	Clear(s_vinit);
+      }
+      Delete(s_vinit);
 
-    Printv(s_init, "PHP_MSHUTDOWN_FUNCTION(", module, ")\n"
-		   "{\n",
-		   s_shutdown,
-		   "#ifdef ZTS\n"
-		   "    ts_free_id(", module, "_globals_id);\n"
-		   "#endif\n"
-		   "    return SUCCESS;\n"
-		   "}\n\n", NIL);
+      Printf(s_init, "    return SUCCESS;\n");
+      Printf(s_init, "}\n\n");
+    }
 
-    Printf(s_init, "PHP_RSHUTDOWN_FUNCTION(%s)\n{\n", module);
-    Printf(s_init, "%s\n", r_shutdown);
-    Printf(s_init, "    return SUCCESS;\n");
-    Printf(s_init, "}\n\n");
+    Printf(f_h, "PHP_MINIT_FUNCTION(%s);\n", module);
+
+    if (Len(s_shutdown) > 0) {
+      Printf(f_h, "PHP_MSHUTDOWN_FUNCTION(%s);\n", module);
+
+      Printv(s_init, "PHP_MSHUTDOWN_FUNCTION(", module, ")\n"
+		     "/* shutdown section */\n"
+		     "{\n",
+		     s_shutdown,
+		     "    return SUCCESS;\n"
+		     "}\n\n", NIL);
+    }
+
+    if (Len(r_shutdown) > 0) {
+      Printf(f_h, "PHP_RSHUTDOWN_FUNCTION(%s);\n", module);
+
+      Printf(s_init, "PHP_RSHUTDOWN_FUNCTION(%s)\n{\n", module);
+      Printf(s_init, "/* rshutdown section */\n");
+      Printf(s_init, "%s\n", r_shutdown);
+      Printf(s_init, "    return SUCCESS;\n");
+      Printf(s_init, "}\n\n");
+    }
+
+    if (Len(pragma_phpinfo) > 0) {
+      Printf(f_h, "PHP_MINFO_FUNCTION(%s);\n", module);
+
+      Printf(s_init, "PHP_MINFO_FUNCTION(%s)\n{\n", module);
+      Printf(s_init, "%s", pragma_phpinfo);
+      Printf(s_init, "}\n");
+    }
 
-    Printf(s_init, "PHP_MINFO_FUNCTION(%s)\n{\n", module);
-    Printf(s_init, "%s", pragma_phpinfo);
-    Printf(s_init, "}\n");
     Printf(s_init, "/* end init section */\n");
 
-    Printf(f_h, "#endif /* PHP_%s_H */\n", cap_module);
+    Printf(f_h, "\n#endif /* PHP_%s_H */\n", cap_module);
 
     Delete(f_h);
 
@@ -648,6 +660,7 @@ public:
     Delete(s_arginfo);
     Delete(f_runtime);
     Delete(f_begin);
+    Delete(arginfo_used);
 
     Printf(f_phpcode, "%s\n%s\n", pragma_incl, pragma_code);
     if (s_fakeoowrappers) {
@@ -667,22 +680,36 @@ public:
   void create_command(String *cname, String *iname, Node *n) {
     // This is for the single main zend_function_entry record
     Printf(f_h, "ZEND_NAMED_FUNCTION(%s);\n", iname);
-    String * s = cs_entry;
-    if (!s) s = s_entry;
-    Printf(s, " SWIG_ZEND_NAMED_FE(%(lower)s,%s,swig_arginfo_%(lower)s)\n", cname, iname, cname);
 
-    // This is the above referenced arginfo structure.
+    // We want to only emit each different arginfo once, as that reduces the
+    // size of both the generated source code and the compiled extension
+    // module.  To do this, we name the arginfo to encode the number of
+    // parameters and which (if any) are passed by reference by using a
+    // sequence of 0s (for non-reference) and 1s (for by references).
     ParmList *l = Getattr(n, "parms");
-    Printf(s_arginfo, "ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_%(lower)s, 0, 0, 0)\n", cname);
+    String * arginfo_code = NewStringEmpty();
     for (Parm *p = l; p; p = Getattr(p, "tmap:in:next")) {
       /* Ignored parameters */
       if (checkAttribute(p, "tmap:in:numinputs", "0")) {
 	continue;
       }
-      int byref = GetFlag(p, "tmap:in:byref");
-      Printf(s_arginfo, " ZEND_ARG_PASS_INFO(%d)\n", byref);
+      Append(arginfo_code, GetFlag(p, "tmap:in:byref") ? "1" : "0");
     }
-    Printf(s_arginfo, "ZEND_END_ARG_INFO()\n");
+
+    if (!GetFlag(arginfo_used, arginfo_code)) {
+      // Not had this one before, so emit it.
+      SetFlag(arginfo_used, arginfo_code);
+      Printf(s_arginfo, "ZEND_BEGIN_ARG_INFO_EX(swig_arginfo_%s, 0, 0, 0)\n", arginfo_code);
+      for (const char * p = Char(arginfo_code); *p; ++p) {
+	Printf(s_arginfo, " ZEND_ARG_PASS_INFO(%c)\n", *p);
+      }
+      Printf(s_arginfo, "ZEND_END_ARG_INFO()\n");
+    }
+
+    String * s = cs_entry;
+    if (!s) s = s_entry;
+    Printf(s, " SWIG_ZEND_NAMED_FE(%(lower)s,%s,swig_arginfo_%s)\n", cname, iname, arginfo_code);
+    Delete(arginfo_code);
   }
 
   /* ------------------------------------------------------------
@@ -710,12 +737,12 @@ public:
 
     Wrapper_add_local(f, "argc", "int argc");
 
-    Printf(tmp, "zval **argv[%d]", maxargs);
+    Printf(tmp, "zval argv[%d]", maxargs);
     Wrapper_add_local(f, "argv", tmp);
 
     Printf(f->code, "argc = ZEND_NUM_ARGS();\n");
 
-    Printf(f->code, "zend_get_parameters_array_ex(argc,argv);\n");
+    Printf(f->code, "zend_get_parameters_array_ex(argc, argv);\n");
 
     Replaceall(dispatch, "$args", "self,args");
 
@@ -723,7 +750,7 @@ public:
 
     Printf(f->code, "SWIG_ErrorCode() = E_ERROR;\n");
     Printf(f->code, "SWIG_ErrorMsg() = \"No matching function for overloaded '%s'\";\n", symname);
-    Printv(f->code, "SWIG_FAIL(TSRMLS_C);\n", NIL);
+    Printv(f->code, "SWIG_FAIL();\n", NIL);
 
     Printv(f->code, "}\n", NIL);
     Wrapper_print(f, s_wrappers);
@@ -819,8 +846,8 @@ public:
     if (num_arguments > 0) {
       String *args = NewStringEmpty();
       if (wrapperType == directorconstructor)
-        Wrapper_add_local(f, "arg0", "zval *arg0");
-      Printf(args, "zval **args[%d]", num_arguments);
+        Wrapper_add_local(f, "arg0", "zval * arg0");
+      Printf(args, "zval args[%d]", num_arguments);
       Wrapper_add_local(f, "args", args);
       Delete(args);
       args = NULL;
@@ -834,7 +861,7 @@ public:
 
     // NOTE: possible we ignore this_ptr as a param for native constructor
 
-    Printf(f->code, "SWIG_ResetError(TSRMLS_C);\n");
+    Printf(f->code, "SWIG_ResetError();\n");
 
     if (numopt > 0) {		// membervariable wrappers do not have optional args
       Wrapper_add_local(f, "arg_count", "int arg_count");
@@ -851,7 +878,7 @@ public:
       Printf(f->code, "WRONG_PARAM_COUNT;\n}\n\n");
     }
     if (wrapperType == directorconstructor)
-      Printf(f->code, "arg0 = *args[0];\n  \n");
+      Printf(f->code, "arg0 = &args[0];\n  \n");
 
     /* Now convert from PHP to C variables */
     // At this point, argcount if used is the number of deliberately passed args
@@ -891,7 +918,7 @@ public:
       }
 
       if ((tm = Getattr(p, "tmap:in"))) {
-	Replaceall(tm, "$source", source);
+	Replaceall(tm, "$source", &source);
 	Replaceall(tm, "$target", ln);
 	Replaceall(tm, "$input", source);
 	Setattr(p, "emit:input", source);
@@ -915,7 +942,7 @@ public:
 
     if (is_member_director(n)) {
       Wrapper_add_local(f, "upcall", "bool upcall = false");
-      Printf(f->code, "upcall = !Swig::Director::swig_is_overridden_method((char *)\"%s%s\", (char *)\"%s\" TSRMLS_CC);\n",
+      Printf(f->code, "upcall = !Swig::Director::swig_is_overridden_method(\"%s%s\", \"%s\");\n",
 	  prefix, Swig_class_name(Swig_methodclass(n)), name);
     }
 
@@ -1000,12 +1027,13 @@ public:
       Delete(tm);
     }
 
+    Printf(f->code, "thrown:\n");
     Printf(f->code, "return;\n");
 
     /* Error handling code */
     Printf(f->code, "fail:\n");
     Printv(f->code, cleanup, NIL);
-    Append(f->code, "SWIG_FAIL(TSRMLS_C);\n");
+    Append(f->code, "SWIG_FAIL();\n");
 
     Printf(f->code, "}\n");
 
@@ -1055,6 +1083,7 @@ public:
       bool handle_as_overload = false;
       String **arg_names;
       String **arg_values;
+      unsigned char * byref;
       // Method or static method or plain function.
       const char *methodname = 0;
       String *output = s_oowrappers;
@@ -1195,7 +1224,8 @@ public:
       }
 
       arg_values = (String **) malloc(max_num_of_arguments * sizeof(String *));
-      if (!arg_values) {
+      byref = (unsigned char *) malloc(max_num_of_arguments);
+      if (!arg_values || !byref) {
 	/* FIXME: How should this be handled?  The rest of SWIG just seems
 	 * to not bother checking for malloc failing! */
 	fprintf(stderr, "Malloc failed!\n");
@@ -1203,6 +1233,7 @@ public:
       }
       for (i = 0; i < max_num_of_arguments; ++i) {
 	arg_values[i] = NULL;
+	byref[i] = false;
       }
 
       Node *o;
@@ -1222,6 +1253,7 @@ public:
 	    continue;
 	  }
 	  assert(0 <= argno && argno < max_num_of_arguments);
+	  byref[argno] = GetFlag(p, "tmap:in:byref");
 	  String *&pname = arg_names[argno];
 	  const char *pname_cstr = GetChar(p, "name");
 	  // Just get rid of the C++ namespace part for now.
@@ -1470,6 +1502,7 @@ public:
 	    Printf(args, ",");
 	  if (i || wrapperType == memberfn)
 	    Printf(invoke, ",");
+	  if (byref[i]) Printf(args, "&");
 	  String *value = arg_values[i];
 	  if (value) {
 	    const char *v = Char(value);
@@ -1478,6 +1511,9 @@ public:
 	      Replaceall(value, "$", "\\$");
 	    }
 	    Printf(args, "$%s=%s", arg_names[i], value);
+	  } else if (constructor && i >= 1 && i < min_num_of_arguments) {
+	    // We need to be able to call __construct($resource).
+	    Printf(args, "$%s=null", arg_names[i]);
 	  } else {
 	    Printf(args, "$%s", arg_names[i]);
 	  }
@@ -1498,6 +1534,15 @@ public:
 	    Printf(invoke_args, ",");
 	}
 	Printf(invoke_args, "%s", args);
+	if (constructor && min_num_of_arguments > 1) {
+	  // We need to be able to call __construct($resource).
+	  Clear(args);
+	  Printf(args, "$%s", arg_names[0]);
+	  for (i = 1; i < min_num_of_arguments; ++i) {
+	    Printf(args, ",");
+	    Printf(args, "$%s=null", arg_names[i]);
+	  }
+	}
 	bool had_a_case = false;
 	int last_handled_i = i - 1;
 	for (; i < max_num_of_arguments; ++i) {
@@ -2289,15 +2334,15 @@ done:
       Delete(director_ctor_code);
       director_ctor_code = NewStringEmpty();
       director_prot_ctor_code = NewStringEmpty();
-      Printf(director_ctor_code, "if ( arg0->type == IS_NULL ) { /* not subclassed */\n");
-      Printf(director_prot_ctor_code, "if ( arg0->type == IS_NULL ) { /* not subclassed */\n");
+      Printf(director_ctor_code, "if (Z_TYPE_P(arg0) == IS_NULL) { /* not subclassed */\n");
+      Printf(director_prot_ctor_code, "if (Z_TYPE_P(arg0) == IS_NULL) { /* not subclassed */\n");
       Printf(director_ctor_code, "  %s = (%s *)new %s(%s);\n", Swig_cresult_name(), ctype, ctype, args);
       Printf(director_prot_ctor_code, "  SWIG_PHP_Error(E_ERROR, \"accessing abstract class or protected constructor\");\n", name, name, args);
       if (i) {
 	Insert(args, 0, ", ");
       }
-      Printf(director_ctor_code, "} else {\n  %s = (%s *)new SwigDirector_%s(arg0 TSRMLS_CC%s);\n}\n", Swig_cresult_name(), ctype, sname, args);
-      Printf(director_prot_ctor_code, "} else {\n  %s = (%s *)new SwigDirector_%s(arg0 TSRMLS_CC%s);\n}\n", Swig_cresult_name(), ctype, sname, args);
+      Printf(director_ctor_code, "} else {\n  %s = (%s *)new SwigDirector_%s(arg0%s);\n}\n", Swig_cresult_name(), ctype, sname, args);
+      Printf(director_prot_ctor_code, "} else {\n  %s = (%s *)new SwigDirector_%s(arg0%s);\n}\n", Swig_cresult_name(), ctype, sname, args);
       Delete(args);
 
       wrapperType = directorconstructor;
@@ -2327,9 +2372,9 @@ done:
     Wrapper *f = NewWrapper();
     Printf(f->def, "/* This function is designed to be called by the zend list destructors */\n");
     Printf(f->def, "/* to typecast and do the actual destruction */\n");
-    Printf(f->def, "static void %s(zend_rsrc_list_entry *rsrc, const char *type_name TSRMLS_DC) {\n", destructorname);
+    Printf(f->def, "static void %s(zend_resource *res, const char *type_name) {\n", destructorname);
 
-    Wrapper_add_localv(f, "value", "swig_object_wrapper *value=(swig_object_wrapper *) rsrc->ptr", NIL);
+    Wrapper_add_localv(f, "value", "swig_object_wrapper *value=(swig_object_wrapper *) res->ptr", NIL);
     Wrapper_add_localv(f, "ptr", "void *ptr=value->ptr", NIL);
     Wrapper_add_localv(f, "newobject", "int newobject=value->newobject", NIL);
 
@@ -2347,7 +2392,7 @@ done:
 
     Printf(f->code, "  efree(value);\n");
     Printf(f->code, "  if (! newobject) return; /* can't delete it! */\n");
-    Printf(f->code, "  arg1 = (%s)SWIG_ZTS_ConvertResourceData(ptr,type_name,SWIGTYPE%s TSRMLS_CC);\n", SwigType_lstr(pt, 0), SwigType_manglestr(pt));
+    Printf(f->code, "  arg1 = (%s)SWIG_ConvertResourceData(ptr, type_name, SWIGTYPE%s);\n", SwigType_lstr(pt, 0), SwigType_manglestr(pt));
     Printf(f->code, "  if (! arg1) zend_error(E_ERROR, \"%s resource already free'd\");\n", Char(name));
 
     Setattr(n, "wrap:name", destructorname);
@@ -2356,9 +2401,10 @@ done:
     Append(f->code, actioncode);
     Delete(actioncode);
 
+    Printf(f->code, "thrown:\n");
     Append(f->code, "return;\n");
     Append(f->code, "fail:\n");
-    Append(f->code, "SWIG_FAIL(TSRMLS_C);\n");
+    Append(f->code, "SWIG_FAIL();\n");
     Printf(f->code, "}\n");
 
     Wrapper_print(f, s_wrappers);
@@ -2418,16 +2464,9 @@ done:
 	String *call;
 	String *basetype = Getattr(parent, "classtype");
 
-	// We put TSRMLS_DC after the self parameter in order to cope with
-	// any default parameters.
 	String *target = Swig_method_decl(0, decl, classname, parms, 0, 0);
-	const char * p = Char(target);
-	const char * comma = strchr(p, ',');
-	int ins = comma ? (int)(comma - p) : Len(target) - 1;
-	Insert(target, ins, " TSRMLS_DC");
-
 	call = Swig_csuperclass_call(0, basetype, superparms);
-	Printf(w->def, "%s::%s: %s, Swig::Director(self TSRMLS_CC) {", classname, target, call);
+	Printf(w->def, "%s::%s: %s, Swig::Director(self) {", classname, target, call);
 	Append(w->def, "}");
 	Delete(target);
 	Wrapper_print(w, f_directors);
@@ -2437,14 +2476,7 @@ done:
 
       /* constructor header */
       {
-	// We put TSRMLS_DC after the self parameter in order to cope with
-	// any default parameters.
 	String *target = Swig_method_decl(0, decl, classname, parms, 0, 1);
-	const char * p = Char(target);
-	const char * comma = strchr(p, ',');
-	int ins = comma ? (int)(comma - p) : Len(target) - 1;
-	Insert(target, ins, " TSRMLS_DC");
-
 	Printf(f_directors_h, "    %s;\n", target);
 	Delete(target);
       }
@@ -2529,8 +2561,6 @@ done:
     Append(w->def, " {");
     Append(declaration, ";\n");
 
-    Printf(w->code, "TSRMLS_FETCH_FROM_CTX(swig_zts_ctx);\n");
-
     /* declare method return value 
      * if the return value is a reference or const reference, a specialized typemap must
      * handle it, including declaration of c_result ($result).
@@ -2551,7 +2581,7 @@ done:
 	Printf(w->code, "%s;\n", super_call);
 	Delete(super_call);
       } else {
-	Printf(w->code, "Swig::DirectorPureVirtualException::raise(\"Attempted to invoke pure virtual method %s::%s\" TSRMLS_CC);\n", SwigType_namestr(c_classname),
+	Printf(w->code, "Swig::DirectorPureVirtualException::raise(\"Attempted to invoke pure virtual method %s::%s\");\n", SwigType_namestr(c_classname),
 	    SwigType_namestr(name));
       }
     } else {
@@ -2566,7 +2596,6 @@ done:
       Swig_typemap_attach_parms("directorargout", l, w);
 
       Parm *p;
-      char source[256];
 
       int outputs = 0;
       if (!is_void)
@@ -2590,16 +2619,11 @@ done:
 	if ((tm = Getattr(p, "tmap:directorin")) != 0) {
 	  String *parse = Getattr(p, "tmap:directorin:parse");
 	  if (!parse) {
-	    sprintf(source, "obj%d", idx++);
-	    String *input = NewStringf("&%s", source);
+	    String *input = NewStringf("&args[%d]", idx++);
 	    Setattr(p, "emit:directorinput", input);
 	    Replaceall(tm, "$input", input);
 	    Delete(input);
 	    Replaceall(tm, "$owner", "0");
-	    Printv(wrap_args, "zval ", source, ";\n", NIL);
-	    Printf(wrap_args, "args[%d] = &%s;\n", idx - 1, source);
-	    Printv(wrap_args, "INIT_ZVAL(", source, ");\n", NIL);
-
 	    Printv(wrap_args, tm, "\n", NIL);
 	    Putc('O', parse_args);
 	  } else {
@@ -2623,6 +2647,7 @@ done:
       }
 
       /* exception handling */
+      bool error_used_in_typemap = false;
       tm = Swig_typemap_lookup("director:except", n, Swig_cresult_name(), 0);
       if (!tm) {
 	tm = Getattr(n, "feature:director:except");
@@ -2632,6 +2657,7 @@ done:
       if ((tm) && Len(tm) && (Strcmp(tm, "1") != 0)) {
 	if (Replaceall(tm, "$error", "error")) {
 	  /* Only declare error if it is used by the typemap. */
+	  error_used_in_typemap = true;
 	  Append(w->code, "int error;\n");
 	}
       } else {
@@ -2640,23 +2666,26 @@ done:
       }
 
       if (!idx) {
-	Printf(w->code, "zval **args = NULL;\n");
+	Printf(w->code, "zval *args = NULL;\n");
       } else {
-	Printf(w->code, "zval *args[%d];\n", idx);
+	Printf(w->code, "zval args[%d];\n", idx);
       }
-      Printf(w->code, "zval *%s, funcname;\n", Swig_cresult_name());
-      Append(w->code, "if (!swig_self) {\n");
-      Append(w->code, "  SWIG_PHP_Error(E_ERROR, \"this pointer is NULL\");");
-      Append(w->code, "}\n\n");
-      Printf(w->code, "MAKE_STD_ZVAL(%s);\n", Swig_cresult_name());
+      // typemap_directorout testcase requires that 0 can be assigned to the
+      // variable named after the result of Swig_cresult_name(), so that can't
+      // be a zval - make it a pointer to one instead.
+      Printf(w->code, "zval swig_zval_result, swig_funcname;\n", Swig_cresult_name());
+      Printf(w->code, "zval * SWIGUNUSED %s = &swig_zval_result;\n", Swig_cresult_name());
       const char * funcname = GetChar(n, "sym:name");
-      Printf(w->code, "ZVAL_STRINGL(&funcname, (char *)\"%s\", %d, 0);\n", funcname, strlen(funcname));
+      Printf(w->code, "ZVAL_STRINGL(&swig_funcname, \"%s\", %d);\n", funcname, strlen(funcname));
 
       /* wrap complex arguments to zvals */
       Printv(w->code, wrap_args, NIL);
 
-      Append(w->code, "call_user_function(EG(function_table), (zval**)&swig_self, &funcname,");
-      Printf(w->code, " %s, %d, args TSRMLS_CC);\n", Swig_cresult_name(), idx);
+      if (error_used_in_typemap) {
+	Append(w->code, "error = ");
+      }
+      Append(w->code, "call_user_function(EG(function_table), &swig_self, &swig_funcname,");
+      Printf(w->code, " &swig_zval_result, %d, args);\n", idx);
 
       if (tm) {
 	Printv(w->code, Str(tm), "\n", NIL);
@@ -2708,13 +2737,12 @@ done:
 	}
       }
 
-      Printf(w->code, "FREE_ZVAL(%s);\n", Swig_cresult_name());
-
       Delete(parse_args);
       Delete(cleanup);
       Delete(outarg);
     }
 
+    Append(w->code, "thrown:\n");
     if (!is_void) {
       if (!(ignored_method && !pure_virtual)) {
 	String *rettype = SwigType_str(returntype, 0);
@@ -2730,7 +2758,7 @@ done:
     }
 
     Append(w->code, "fail:\n");
-    Append(w->code, "SWIG_FAIL(TSRMLS_C);\n");
+    Append(w->code, "SWIG_FAIL();\n");
     Append(w->code, "}\n");
 
     // We expose protected methods via an extra public inline method which makes a straight call to the wrapped class' method
@@ -2775,7 +2803,8 @@ static PHP *maininstance = 0;
 // We use this function to be able to write out zend_register_list_destructor_ex
 // lines for most things in the type table
 // NOTE: it's a function NOT A PHP::METHOD
-extern "C" void typetrace(const SwigType *ty, String *mangled, String *clientdata) {
+extern "C" {
+static void typetrace(const SwigType *ty, String *mangled, String *clientdata) {
   Node *class_node;
   if (!zend_types) {
     zend_types = NewHash();
@@ -2795,6 +2824,7 @@ extern "C" void typetrace(const SwigType *ty, String *mangled, String *clientdat
   if (r_prevtracefunc)
     (*r_prevtracefunc) (ty, mangled, (String *) clientdata);
 }
+}
 
 /* -----------------------------------------------------------------------------
  * new_swig_php()    - Instantiate module
@@ -2811,13 +2841,6 @@ static Language *new_swig_php() {
   return maininstance;
 }
 
-extern "C" Language *swig_php4(void) {
-  Printf(stderr, "*** -php4 is no longer supported.\n"
-		 "*** Either upgrade to PHP5 or use SWIG 1.3.36 or earlier.\n");
-  SWIG_exit(EXIT_FAILURE);
-  return NULL; // To avoid compiler warnings.
-}
-
 extern "C" Language *swig_php(void) {
   return new_swig_php();
 }
